@@ -8,8 +8,13 @@ use List::Util qw[first];
 use Text::Balanced qw[extract_delimited extract_multiple];
 use Moo;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
+has slash_as_delim => (
+    is      => q(rw),
+    isa     => sub { ( $_[0] == 0 || $_[0] == 1 ) or die },
+    default => 0,
+);
 has operators => (
     is      => q(ro),
     default => sub {
@@ -50,10 +55,17 @@ sub tokenizer {
 
     my $op = join qq(\N{VERTICAL LINE}), keys %{ $self->operators() };
 
-    my @expression = extract_multiple(
-        $expression,    #
-        [ sub { extract_delimited( $_[0], '/' ) } ],    #
-    );
+    my @expression;
+    if ( $self->slash_as_delim() ) {
+        @expression = extract_multiple(
+            $expression,    #
+            [ sub { extract_delimited( $_[0], '/' ) } ],    #
+        );
+    }
+    else {
+        @expression = $expression;
+        $expression[0] =~ s{\N{SOLIDUS}}{\N{REVERSE SOLIDUS}\N{SOLIDUS}}gmsx;
+    }
 
     foreach (@expression) {
 
@@ -73,7 +85,7 @@ sub tokenizer {
          {\N{LINE FEED}$1\N{LINE FEED}}gmsx;
 
         s{(?:\A|\s)(${op})(?=\s|\z)}         # OPERATORS
-         {\N{LINE FEED}$1\N{LINE FEED}}gmsx;
+         {\N{LINE FEED}$1\N{LINE FEED}}gimsx;
 
         s{\A\p{IsSpace}+}{}msx;
         s{\p{IsSpace}+\z}{}msx;
@@ -92,8 +104,8 @@ sub tokenizer {
         {
             $token = [ q(PARENTHESIS), $token ];
         }
-        elsif ( exists $self->operators->{$token} ) {
-            $token = [ q(OPERATOR), $token ],;
+        elsif ( exists $self->operators->{uc $token} ) {
+            $token = [ q(OPERATOR), uc $token ],;
         }
         else {
             if ($token =~    #
@@ -203,7 +215,7 @@ App::BoolFindGrep::Bool - parse and/or solve context matching of a boolean expre
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
